import os

import vtx_common.utils as v_utils
import vtx_common.tests.common as t_common

class TestUtils(t_common.TstBase):

    def test_gitdir(self):

        with self.getTempdir() as dirn:
            self.false(v_utils.reqGitDir(dirn))
            os.makedirs(os.path.join(dirn, '.git'))
            self.true(v_utils.reqGitDir(dirn))

    def test_system(self):
        cwd = os.getcwd()
        buf = v_utils.system('pwd')
        system_pwd = buf.decode()
        system_pwd = system_pwd.strip()
        self.eq(cwd, system_pwd)



import os
import sys
import asyncio
import logging
import argparse

import yaml

logger = logging.getLogger(__name__)


def yamlload(fp):
    with open(fp, mode='rb') as fd:
        byts = fd.read()
    if not byts:
        return None
    return yaml.safe_load(byts.decode('utf8'))

def getMessageFromPkg(pkg, mtyp):
    minv = pkg.get('synapse_minversion')
    if minv:
        assert len(minv) == 3
        minv = [str(v) for v in minv]
        minv = '.'.join(minv)
        mesg = f'{mtyp} requires a minimum Synapse version of {minv} or greater.'
    else:
        mesg = f'{mtyp} has no minimum Synapse version specified.'
    return mesg


def main(argv):
    pars = makeargparser()
    opts = pars.parse_args(argv)

    assert os.path.isfile(opts.file)
    pkg = yamlload(opts.file)
    assert pkg is not None
    mesg = getMessageFromPkg(pkg, opts.type)
    print(mesg)
    return 0

def makeargparser():
    desc = 'Extract a minimum version string from a storm package.'
    pars = argparse.ArgumentParser('vtx_common.tools.get_pkg_syn_minver', description=desc)

    pars.add_argument('file', type=str,
                      help='Storm package file to extract from.')
    pars.add_argument('-t', '--type', action='store', type=str, required=True,
                      help='string type to print')

    return pars


if __name__ == '__main__':  # pragma: no cover
    main(sys.argv[1:])



import os
import sys
import json
import shutil
import asyncio
import logging
import argparse

try:
    import synapse.common as s_common
    import synapse.tools.rstorm as s_rstorm
    import synapse.tools.autodoc as s_autodoc
except ImportError:
    s_common = None
    s_rstorm = None
    s_autodoc = None

logger = logging.getLogger(__name__)

logging.getLogger('vcr').setLevel(logging.WARNING)

def hasPandoc():
    if os.system('pandoc --version') == 0:
        return True
    return False

async def buildPkgDocs(opts):

    pkgpath = opts.pkgfile
    logger.info(f'Building pkg for {pkgpath}')
    pkgdef = s_common.yamlload(pkgpath)
    assert pkgdef is not None

    dirn = os.path.dirname(s_common.genpath(pkgpath))

    docsdir = os.path.join(dirn, 'docs')
    builddir = os.path.join(dirn, 'docs', '_build')

    shutil.rmtree(builddir, ignore_errors=True)

    s_common.gendir(builddir)

    # touch any files we need in order to load a package, due to
    # rstorm needing to load the package using genpkg tool. This
    # does mean that standalone builds of a storm package from this
    # repo must be done after using this buildpkg tool.
    stormpkg_md_present = False
    for dnfo in pkgdef.get('docs', ()):
        fpath = dnfo.get('path')
        with s_common.genfile(dirn, fpath) as fd:
            pass
        if fpath.endswith('stormpackage.md'):
            stormpkg_md_present = True

    # Generate the build .RST for stormpackage.md
    if stormpkg_md_present:
        logger.info(f'Generating stormpkg.rst for {pkgpath}')
        pkgdocs, pkgname = await s_autodoc.docStormpkg(pkgpath)
        with s_common.genfile(docsdir, 'stormpackage.rst') as fd:
            text = pkgdocs.getRstText()
            if opts.rst_only is False:
                # Leave this in place if we're only generating RST
                text = text.replace('.. highlight:: none\n', '')
            fd.write(text.encode())
        logger.info('Generated the stormpackage.rst file!')

    for name in os.listdir(docsdir):

        if not name.endswith('.rst'):
            continue

        docpath = os.path.join(docsdir, name)

        basename = name.rsplit('.', 1)[0]

        builtmd = os.path.join(builddir, f'{basename}.md')
        builtrst = os.path.join(builddir, name)

        argv = (docpath, '--save', builtrst)
        logger.info(f'Executing rstorm for {argv}')
        await s_rstorm.main(argv)

        if opts.rst_only:
            logger.info(f'rst_only enabled, done processing {name}')
            continue

        logger.info('Preprocessing rstorm output')
        with s_common.genfile(builtrst) as fd:
            buf = fd.read().decode()

        # Remove highglight:: none directives
        buf = buf.replace('.. highlight:: none\n', '')
        lines = buf.splitlines(keepends=True)

        # Remove lines which start with explicit sphinx rst targets
        nlines1 = []
        for line in lines:
            if line.startswith('.. _') and line.strip().endswith(':'):
                logger.info(f'Dropping: [{line.strip()}]')
                continue
            nlines1.append(line)

        buf = ''.join(nlines1)

        with s_common.genfile(builtrst) as fd:
            fd.truncate()
            _ = fd.write(buf.encode())

        logger.info(f'Converting {builtrst} to markdown')
        os.system(f'pandoc -f rst -t markdown -o {builtmd} {builtrst}')

        logger.info(f'Done converting {builtrst} to {builtmd}')

        # Strip out / manipupate the md content
        with s_common.genfile(builtmd) as fd:
            buf = fd.read().decode()

        lines = buf.splitlines(keepends=True)

        # Remove lines which only have a single `:` left in them
        nlines1 = [line for line in lines if line.strip() != ':']

        buf = ''.join(nlines1)

        with s_common.genfile(builtmd) as fd:
            fd.truncate()
            _ = fd.write(buf.encode())

        logger.info('Done manipulating markdown')

    logger.info(f'buildPkgDocs complete for {pkgpath}.')

prog = 'vtx_common.tools.buildpkg'
desc = 'A tool for building storm-package docs.'

async def main(argv):

    if s_common is None:
        logger.error('The synapse package must be installed to use the {prog} tool.')
        return 1

    pars = argparse.ArgumentParser(prog=prog, description=desc)
    pars.add_argument('pkgfile', metavar='<pkgfile>', help='Path to a storm package prototype yml file.')
    pars.add_argument('--rst-only', default=False, action='store_true',
                      help='Stops building after the .rst files have been generated.')

    opts = pars.parse_args(argv)

    if opts.rst_only is False and not hasPandoc():
        logger.error('Pandoc is not available, can only run rst/rstorm output.')
        return 1

    await buildPkgDocs(opts)

    return 0

if __name__ == '__main__': # pragma: no cover
    s_common.setlogging(logger, 'DEBUG')
    sys.exit(asyncio.run(main(sys.argv[1:])))



import os
import argparse

import vtx_common.tests.common as t_common
import vtx_common.tools.github_release as v_ghr


synapse_changelog = '''

v2.7.3 - 2020-09-16
===================

Deprecations
------------

- The ``0.1.x`` to ``2.x.x`` Migration tool and and associated Cortex sync service will be removed from Synapse in
  the ``2.9.0`` release. In order to move forward to ``2.9.0``, please make sure that any Cortexes which still need to
  be migrated will first be migrated to ``2.8.x`` prior to attempting to use ``2.9.x``.
  (`#1880 <https://github.com/vertexproject/synapse/pull/1880>`_)

Bugfixes
--------
- Remove duplicate words in a comment. This was a community contribution from enadjoe.
  (`#1874 <https://github.com/vertexproject/synapse/pull/1874>`_)
- Fix a nested Nexus log event in Storm Service deletion. The ``del`` event causing Storm code execution could lead to
  nested Nexus events, which is incongruent with how Nexus change handlers work. This now spins off the Storm code in
  a free-running coroutine. This does change the service ``del`` semantics since any support Storm packages a service
  had may be removed by the time the handler executes.
  (`#1876 <https://github.com/vertexproject/synapse/pull/1876>`_)
- Fix an issue where the ``cull`` parameter was not being passed to the multiqueue properly when calling ``.gets()``
  on a Storm Types Queue object.
  (`#1876 <https://github.com/vertexproject/synapse/pull/1876>`_)
- Pin the ``nbconvert`` package to a known working version, as ``v6.0.0`` of that package broke the Synapse document
  generation by changing how templates work.
  (`#1876 <https://github.com/vertexproject/synapse/pull/1876>`_)
- Correct ``min`` and ``max`` integer examples in tagprop documentation and tests.
  (`#1878 <https://github.com/vertexproject/synapse/pull/1878>`_)


v2.7.2 - 2020-09-04
===================

Features and Enhancements
-------------------------
- Update tests for additional test code coverage. This was a community contribution from blackout.
  (`#1867 <https://github.com/vertexproject/synapse/pull/1867>`_)
- Add implicit links to documentation generated for Storm services, to allow for direct linking inside of documentation
  to specific Storm commands.
  (`#1866 <https://github.com/vertexproject/synapse/pull/1866>`_)
- Add future support for deprecating model elements in the Synapse data model. This support will produce client and
  server side warnings when deprecated model elements are used or loaded by custom model extensions or CoreModules.
  (`#1863 <https://github.com/vertexproject/synapse/pull/1863>`_)

Bugfixes
--------
- Update ``FixedCache.put()`` to avoid a cache miss. This was a community contribution from blackout.
  (`#1868 <https://github.com/vertexproject/synapse/pull/1868>`_)
- Fix the ioloop construction to be aware of ``SYN_GREEDY_CORO`` environment variable to put the ioloop into debug mode
  and log long-running coroutines.
  (`#1870 <https://github.com/vertexproject/synapse/pull/1870>`_)
- Fix how service permissions are checked in ``$lib.service.get()`` and ``$lib.service.wait()`` Storm library calls.
  These APIs now first check ``service.get.<service iden>`` before checking ``service.get.<service name>`` permissions.
  A successful ``service.get.<service name>`` check will result in a warning to the client and the server.
  (`#1871 <https://github.com/vertexproject/synapse/pull/1871>`_)


v2.7.1 - 2020-08-26
===================

Features and Enhancements
-------------------------
- Refactor an Axon unit test to make it easier to test alternative Axon implementations.
  (`#1862 <https://github.com/vertexproject/synapse/pull/1862>`_)

Bugfixes
--------
- Fix an issue in ``synapse.tools.cmdr`` where it did not ensure that the users Synapse directory was created before
  trying to open files in the directory.
  (`#1860 <https://github.com/vertexproject/synapse/issues/1860>`_)
  (`#1861 <https://github.com/vertexproject/synapse/pull/1861>`_)

Improved Documentation
----------------------
- Fix an incorrect statement in our documentation about the intrinsic Axon that a Cortex creates being remotely
  accessible.
  (`#1862 <https://github.com/vertexproject/synapse/pull/1862>`_)
'''

setup_cfg = '''

[vtx_common:github_release]
release-name = Vertex Common Tools
extra-lines = Words go here

              More words go here!
dry-run = true
remove-urls = false
nope = does not matter
test-int = 1138
'''

extra_lines = '''Words go here

More words go here!'''

class TestGithubRelease(t_common.TstBase):

    def test_changelog(self):

        logs = v_ghr.parse_changelog(synapse_changelog)
        self.eq(3, len(logs))
        self.eq(set(logs.keys()),
                         {'v2.7.1', 'v2.7.2', 'v2.7.3'})

        lines = logs.get('v2.7.1')
        line = '  (`#1860 <https://github.com/vertexproject/synapse/issues/1860>`_)'
        self.true(line in lines)
        line = '- Refactor an Axon unit test to make it easier to test alternative Axon implementations.'
        self.true(line in lines)

        line = '  (`#1880 <https://github.com/vertexproject/synapse/pull/1880>`_)'
        self.false(line in lines)

        nlines = v_ghr.remove_urls(lines)
        line = '  (`#1860 <https://github.com/vertexproject/synapse/issues/1860>`_)'
        self.false(line in nlines)
        line = '- Refactor an Axon unit test to make it easier to test alternative Axon implementations.'
        self.true(line in nlines)

    def test_setup_parse(self):

        v_ghr.CFG_OPTS['test-int'] = {
            'type': 'int',
            'key': 'test_int',
        }
        v_ghr.CFG_OPTS['test-str'] = {
            'type': 'str',
            'key': 'test_str',
            'defval': 'test'
        }

        with self.getTempdir() as dirn:
            fp = os.path.join(dirn, 'temp.cfg')
            with open(fp, 'wb') as fd:
                fd.write(setup_cfg.encode())

            opts = argparse.Namespace()
            self.eq(vars(opts), {})
            v_ghr.pars_config(opts, fp)
            info = vars(opts)

            self.len(7, info)
            self.eq(info.get('dryrun'), True)
            self.eq(info.get('remove_urls'), False)
            self.eq(info.get('test_int'), 1138)
            self.eq(info.get('release_name'), 'Vertex Common Tools')
            self.eq(info.get('extra_lines'), extra_lines)
            self.eq(info.get('test_str'), 'test')



import shutil
import tempfile
import unittest
import contextlib

class TstBase(unittest.TestCase):

    @contextlib.contextmanager
    def getTempdir(self):
        tempdir = tempfile.mkdtemp()
        try:
            yield tempdir
        finally:
            shutil.rmtree(tempdir)

    def eq(self, a, b):
        self.assertEqual(a, b)

    def ne(self, a, b):
        self.assertNotEqual(a, b)

    def len(self, n, obj):
        self.eq(n, len(obj))

    def true(self, expr):
        self.assertTrue(expr)

    def false(self, expr):
        self.assertFalse(expr)

    def nn(self, x, msg=None):
        '''
        Assert X is not None
        '''
        self.assertIsNotNone(x, msg=msg)

    def none(self, x, msg=None):
        '''
        Assert X is None
        '''
        self.assertIsNone(x, msg=msg)

    def raises(self, *args, **kwargs):
        '''
        Assert a function raises an exception.
        '''
        return self.assertRaises(*args, **kwargs)

    def isinstance(self, obj, cls, msg=None):
        '''
        Assert a object is the instance of a given class or tuple of classes.
        '''
        self.assertIsInstance(obj, cls, msg=msg)

    def isin(self, member, container, msg=None):
        '''
        Assert a member is inside of a container.
        '''
        self.assertIn(member, container, msg=msg)

    def notin(self, member, container, msg=None):
        '''
        Assert a member is not inside of a container.
        '''
        self.assertNotIn(member, container, msg=msg)



import os
import yaml

import vtx_common.tests.common as t_common
import vtx_common.tools.get_pkg_syn_minver as v_gpsm


def_pkg = {
    'name': 'foo',
    'version': [1, 0, 0],
    'synapse_minversion': [2, 48, 0],
    'modules': [
        {
            'name': 'foo',
            'storm': ''
        },
    ],
}


class TestGpsm(t_common.TstBase):

    def test_gpsm(self):
        with self.getTempdir() as dirn:
            fp = os.path.join(dirn, 'test.yaml')

            with open(fp, 'w') as fd:
                yaml.safe_dump(def_pkg, fd)

            pkg = v_gpsm.yamlload(fp)
            self.eq(pkg, def_pkg)

            mesg = v_gpsm.getMessageFromPkg(pkg, 'Power-Up')
            self.eq(mesg, 'Power-Up requires a minimum Synapse version of 2.48.0 or greater.')

            pkg.pop('synapse_minversion')
            mesg = v_gpsm.getMessageFromPkg(pkg, 'Power-Up')
            self.eq(mesg, 'Power-Up has no minimum Synapse version specified.')



#!/usr/bin/env python
import os
import sys
from setuptools import setup, find_packages
from setuptools.command.install import install

VERSION = '0.1.17'

class VerifyVersionCommand(install):
    """Custom command to verify that the git tag matches our version"""
    description = 'verify that the git tag matches our version'

    def run(self):
        tag = os.getenv('CIRCLE_TAG', '')
        tag = tag.lstrip('v')

        if tag != VERSION:
            info = f"Git tag: {tag} does not match the version of this app: {VERSION}"
            sys.exit(info)

long_description_content_type = None
long_description = None
readme = './README.rst'
if os.path.exists(readme):

    print(f'Adding {readme} contents as the long description.')

    with open('./README.rst', 'rb') as fd:
        buf = fd.read()
    long_description = buf.decode()
    long_description_content_type = 'text/x-rst'


setup(
    name='vtx-common',
    version=VERSION,
    description='Vertex project tools to assist with packaging.',
    long_description=long_description,
    long_description_content_type=long_description_content_type,
    author='The Vertex Project LLC',
    author_email='epiphyte+tools@vertex.link',
    url='https://github.com/vertexproject/common-tools',
    license='Apache License 2.0',

    packages=find_packages(exclude=['scripts',
                                    ]),

    include_package_data=True,

    install_requires=[
        'PyGithub==1.53',
        'PyYAML>=5.4,<6.1.0',
        'bump2version==1.0.1',
        'pytest>=7.2.0,<8.0.0',
        'autopep8>=1.5.3,<2.0.0',
        'pytest-cov>=4.0.0,<5.0.0',
        'pycodestyle>=2.6.0,<3.0.0',
        'pytest-xdist>=3.0.2,<4.0.0',
    ],
    extras_require={
        'synapse': [
            'synapse>=2.115.1,<3.0.0',
        ]
    },

    classifiers=[
        'Development Status :: 4 - Beta',

        'License :: OSI Approved :: Apache Software License',

        'Topic :: System :: Clustering',
        'Topic :: System :: Distributed Computing',
        'Topic :: System :: Software Distribution',

        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
    ],
    cmdclass={
        'verify': VerifyVersionCommand,
    },
)



import re
import os
import sys
import logging
import argparse
import collections
import configparser

from typing import List, AnyStr

import github

import vtx_common.tools.get_pkg_syn_minver as v_gpsm


HEADER_RE = r'v[0-9]+\.[0-9]+\.[0-9]+((a|b|rc)[0-9]*)?\s-\s20[0-9]{2}-[0-9]{2}-[0-9]{2}'
PASSLINE = r'^=.*$'
SEMVER_RE = r'v[0-9]+\.[0-9]+\.[0-9]+(?P<pre>((a|b|rc)[0-9]*)?)'
URL_RE = r'\s+\(`#\d+\s<http'
logger = logging.getLogger(__name__)

CFG_HEADER = 'vtx_common:github_release'

DRYRUN = 'dryrun'
CHANGELOG = 'changelog'
CHANGELOG_PKGNAME = 'changelog_pkgname'
REMOVE_URLS = 'remove_urls'
RELEASE_NAME = 'release_name'
RELEASE_NAME_PKGNAME = 'release_name_pkgname'
STORM_PKG_FILE = 'storm_pkg_file'
STORM_PKG_FILE_PKGNAME = 'storm_pkg_file_pkgname'
STORM_PKG_TYPE = 'storm_pkg_type'
STORM_PKG_TYPE_PKGNAME = 'storm_pkg_type_pkgname'

CFG_OPTS = {
    'release-name': {
        'type': 'str',
        'key': RELEASE_NAME,
    },
    'release-name-pkgname': {
        'type': 'bool',
        'key': RELEASE_NAME_PKGNAME,
    },
    'extra-lines': {
        'type': 'str',
        'key': 'extra_lines',
        'defval': ''
    },
    'remove-urls': {
        'type': 'bool',
        'key': REMOVE_URLS,
    },
    'dry-run': {
        'type': 'bool',
        'key': DRYRUN,
    },
    'storm-pkg-file': {
        'type': 'str',
        'key': STORM_PKG_FILE,
    },
    'storm-pkg-file-pkgname': {
        'type': 'bool',
        'key': STORM_PKG_FILE_PKGNAME,
    },
    'storm-pkg-type': {
        'type': 'str',
        'key': STORM_PKG_TYPE,
        'defval': 'Synapse Power-Up',
    },
    'storm-pkg-type-pkgname': {
        'type': 'bool',
        'key': STORM_PKG_TYPE_PKGNAME,
    },
    'changelog': {
        'type': 'str',
        'key': CHANGELOG,
    },
    'changelog-pkgname': {
        'type': 'bool',
        'key': CHANGELOG_PKGNAME,
    },
}

def get_parser():
    pars = argparse.ArgumentParser()
    pars.add_argument('-g', '--github-token', dest='gittokenvar', default='GITHUB_TOKEN', type=str,
                      help='Environment variable to pull the github token from.')
    pars.add_argument('-u', '--github-user', dest='gituservar', default='CIRCLE_PROJECT_USERNAME', type=str,
                      help='Environment variable to pull the github user from')
    pars.add_argument('-r', '--github-repo', dest='gitrepovar', default='CIRCLE_PROJECT_REPONAME', type=str,
                      help='Environment variable to pull the github repo from')
    pars.add_argument('-t', '--tagvar', dest='tagvar', default='CIRCLE_TAG', type=str,
                      help='Environment variable to pull the tag from.')
    pars.add_argument('-c', '--changelog', dest=CHANGELOG, default='./CHANGELOG.rst',
                      help='Path to changelog file to process')
    pars.add_argument('--changelog-pkgname', dest=CHANGELOG_PKGNAME, default=False, action='store_true',
                      help='inject package name derived from a tag into the changelog path.')
    pars.add_argument('--remove-urls', dest=REMOVE_URLS, default=False, action='store_true',
                      help='Remove lines starting with RST formated links.')
    pars.add_argument('-d', '--dry-run', dest=DRYRUN, default=False, action='store_true',
                      help='Do not do an actual Github release action. Does not require github variables to be set.'
                           'Does require the tag variable to be set. This will print the changlog found to stderr.')
    pars.add_argument('--release-name', dest=RELEASE_NAME, default=None, type=str,
                      help='Release name to prefix the tag with for the github release.')
    pars.add_argument('--release-name-pkgname', dest=RELEASE_NAME_PKGNAME, default=None, action='store_true',
                      help='inject pkgname derived from a tag into the release name')
    pars.add_argument('--pkg-file', dest=STORM_PKG_FILE, default=None, type=str,
                      help='Storm package file to get minimum storm service from.')
    pars.add_argument('--pkg-file-inject', dest=STORM_PKG_FILE_PKGNAME, default=False, action='store_true',
                      help='inject pkgname derived from a tag into the pkgpath path')
    pars.add_argument('--pkg-type', dest=STORM_PKG_TYPE, type=str,
                      help='minver string name.')
    pars.add_argument('--pkg-type-pkgname', dest=STORM_PKG_TYPE_PKGNAME, action='store_true',
                      help='inject the pkgname derviced from a tag into the minver string name')

    return pars

def parse_changelog(s: str) -> dict:
    curv = None
    ret = collections.defaultdict(list)
    for line in s.split('\n'):
        if re.match(HEADER_RE, line):
            curv = line.split(' ', 1)[0]
            continue
        if re.match(PASSLINE, line):
            continue
        if curv:
            ret[curv].append(line)

    return ret

def remove_urls(lines: List[AnyStr]) -> List[AnyStr]:
    ret = []
    for line in lines:
        if re.search(URL_RE, line):
            continue
        ret.append(line)
    return ret

def pars_config(opts: argparse.Namespace,
                fn: AnyStr,
                ):
    if not os.path.exists(fn):
        logger.debug('Config file [{}] does not exist.')
        return

    config = configparser.RawConfigParser()
    config.read(fn)

    if not config.has_section(CFG_HEADER):
        logger.info(f'No {CFG_HEADER} header found')

    for opt, info in CFG_OPTS.items():
        typ = info.get('type')
        defval = info.get('defval')
        try:
            if typ == 'bool':
                valu = config.getboolean(CFG_HEADER, opt)
            elif typ == 'int':
                valu = config.getint(CFG_HEADER, opt)
            else:
                valu = config.get(CFG_HEADER, opt,)
        except (configparser.NoOptionError, configparser.NoSectionError):
            if defval is None:
                continue
            valu = defval

        setattr(opts, info.get('key'), valu)

    logger.info(f'Parsed {opts} from setup.cfg')
    return

def main(argv):
    pars = get_parser()

    opts = argparse.Namespace()
    pars_config(opts, 'setup.cfg')

    opts = pars.parse_args(argv, namespace=opts)
    logger.info(f'Final namespace: {opts}')

    tag = os.getenv(opts.tagvar, '')
    if not tag:
        logger.error(f'No tag found for {opts.tagvar}')
        return 1

    logger.info(f'envar {opts.tagvar} resolved to {tag}')
    nicetag = tag
    pkgname = None
    if '@' in tag:
        logger.info('@ delimited tag, splitting into name and tag part')
        pkgname, nicetag = tag.split('@')
        logger.info(f'Got pkgname={pkgname} @ nicetag={nicetag}')
    m = re.search(SEMVER_RE, nicetag)
    if not m:
        logger.error(f'nicetag={nicetag} does not match semver regex')
        return 1
    is_prerelease = False
    if m.groupdict().get('pre'):
        is_prerelease = True

    defvalu = ''
    if not opts.dryrun:
        envd = os.getenv('VTX_COMMON_DRYRUN', None)
        if envd is not None:
            logger.info('Setting opts.dryrun to True from environment variable')
            opts.dryrun = True
    if opts.dryrun:
        defvalu = 'DRYRUN'

    gh_token = os.getenv(opts.gittokenvar, defvalu)
    if not gh_token:
        logger.error('No github token found')
        return 1
    gh_username = os.getenv(opts.gituservar, defvalu)
    if not gh_username:
        logger.error('No github user found')
        return 1
    gh_repo = os.getenv(opts.gitrepovar, defvalu)
    if not gh_repo:
        logger.error('No github repo found')
        return 1

    extra_parts = []

    pfile = opts.storm_pkg_file
    mtyp = opts.storm_pkg_type
    if pfile and mtyp:

        if opts.storm_pkg_file_pkgname:
            assert pkgname is not None
            logger.info('Injecting pkgname to pkg path')
            pfile = pfile.format(pkgname=pkgname)

        if opts.storm_pkg_type_pkgname:
            assert pkgname is not None
            logger.info('Injecting pkgname to pkg mtype')
            mtyp = mtyp.format(pkgname=pkgname)

        logger.info(f'Getting storm package from {pfile}')
        pkg = v_gpsm.yamlload(pfile)
        minv_message = v_gpsm.getMessageFromPkg(pkg, mtyp)
        logger.info(f'Got message: {minv_message}')
        extra_parts.append(minv_message)

    extra_lines = opts.extra_lines
    if extra_lines:
        logger.info(f'Extra lines found: {extra_lines}')
        extra_parts.append(extra_lines)

    # Join extra lines together
    extra_lines = '\n'.join(extra_parts)

    changelog_fp = opts.changelog
    if opts.changelog_pkgname:
        assert pkgname is not None
        logger.info('Injecting pkgname to changelog path')
        changelog_fp = changelog_fp.format(pkgname=pkgname)

    assert os.path.isfile(changelog_fp)
    raw_changelog = open(changelog_fp, 'rb').read().decode()
    parsed_logs = parse_changelog(raw_changelog)

    target_log = parsed_logs.get(nicetag)
    if not target_log:
        logger.error(f'Unable to find logs for tag [{nicetag}]')
        # It's possible for pre-release tags to end up without a changelog.
        # This condition should not end up failing a CI pipeline.
        return 0
    logger.info(f'Found changelogs for [{nicetag}] in [{changelog_fp}]')

    if opts.remove_urls:
        logger.info('Removing URLs')
        target_log = remove_urls(target_log)

    # join logs together and strip them
    target_log = '\n'.join(target_log)
    target_log = target_log.strip()

    if extra_lines:
        logger.info(f'Appending extra line data')
        target_log = '\n'.join([target_log, '', extra_lines])
        # remove trailing data if present in extra_lines
        target_log = target_log.strip()

    logger.info('Final Log:')
    for line in target_log.split('\n'):
        logger.debug(line)

    name = nicetag
    if opts.release_name:
        name = f'{opts.release_name} {nicetag}'
    if opts.release_name_pkgname:
        logger.info(f'Injecting pkgname into [{name}]')
        name = name.format(pkgname=pkgname)
        logger.info(f'Name is now [{name}]')

    logger.info(f'Release Name: [{name}]')
    gh_repo_path = f'{gh_username}/{gh_repo}'

    if opts.dryrun:
        logger.info('Dry-run mode enabled. Not performing a Github release action.')
        logger.info('Would have made release with the following information:')
        logger.info(f'gh_repo_path={gh_repo_path}')
        logger.info(f'tag={tag}')
        logger.info(f'name={name}')
        logger.info(f'prerelease={is_prerelease}')
        logger.info(f'message={target_log}')
        return 0

    gh = github.Github(gh_token)

    logger.info(f'Getting github repo for {gh_repo_path}')
    repo = gh.get_repo(gh_repo_path)

    logger.info('Making github release')
    release = repo.create_git_release(tag=tag,
                                      name=name,
                                      draft=False,
                                      message=target_log,
                                      prerelease=is_prerelease,
                                      )
    logger.info(f'Made github release {release}')

    return 0

if __name__ == '__main__':
    logging.basicConfig(level=logging.DEBUG)
    sys.exit(main(sys.argv[1:]))



import os
import asyncio

import vtx_common.utils as v_utils
import vtx_common.tests.common as t_common
try:
    import vtx_common.tools.buildpkg as vt_buildpkg
except ImportError:
    vt_buildpkg = None

curdir = os.path.split(__file__)[0]
testpkgdir = os.path.join(curdir, 'testpkg')
testpkgfp = os.path.join(testpkgdir, 'testpkg.yaml')

class TestBuildpkg(t_common.TstBase):
    def test_buildpkg(self):
        if vt_buildpkg.s_common is None:
            self.skipTest('Synapse library is unavailable to test buildpkg tool with.')

        self.true(os.path.isfile(testpkgfp))
        argv = [testpkgfp, ]
        r = asyncio.run(vt_buildpkg.main(argv))
        self.eq(r, 0)

        import synapse.common as s_common

        pkgdef = s_common.yamlload(testpkgfp)
        efiles = set()
        for dnfo in pkgdef.get('docs'):
            bname = os.path.basename(dnfo.get('path'))
            efiles.add(bname)
            efiles.add(bname.rsplit('.', 1)[0] + '.rst')
        builddir = os.path.join(testpkgdir, 'docs', '_build')
        self.eq(efiles, set(os.listdir(builddir)))
